erand48

Function erand48 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn erand48(xsubi: *mut c_ushort) -> c_double
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/drand48.html.

Safety

The caller must ensure that xsubi is convertible to a &mut [c_ushort; 3].

Panics

Panics if the function is unable to obtain a lock on the generator’s global state.