#[unsafe(no_mangle)]pub extern "C" fn lrand48() -> c_longExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/drand48.html.
Panics
Panics if the function is unable to obtain a lock on the generator’s global state.
#[unsafe(no_mangle)]pub extern "C" fn lrand48() -> c_longSee https://pubs.opengroup.org/onlinepubs/9799919799/functions/drand48.html.
Panics if the function is unable to obtain a lock on the generator’s global state.