seed48

Function seed48 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn seed48( seed16v: *mut c_ushort, ) -> *mut c_ushort
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/drand48.html.

Safety

The caller must ensure that seed16v is convertible to a &[c_ushort; 3]. Additionally, the caller must ensure that the function has exclusive access to the static buffer it returns; this includes avoiding simultaneous calls to this function.

Panics

Panics if the function is unable to obtain a lock on the generator’s global state.