strtoul

Function strtoul 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn strtoul( str: *const c_char, endptr: *mut *mut c_char, base: c_int, ) -> c_ulong
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/strtoul.html.

Converts the initial portion of the string pointed to by str to a type unsigned long.

Upon success, returns the converted value. If no conversion could be performed or the value of base is not supported, returns 0.