#[unsafe(no_mangle)]pub unsafe extern "C" fn lcong48(param: *mut c_ushort)Expand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/drand48.html.
Safety
The caller must ensure that param is convertible to a
&mut [c_ushort; 7].
Panics
Panics if the function is unable to obtain a lock on the generator’s global state.