#[unsafe(no_mangle)]pub unsafe extern "C" fn strtoll(
nptr: *const c_char,
endptr: *mut *mut c_char,
base: c_int,
) -> c_longlongExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/strtol.html.
Converts the initial portion of the string pointed to by nptr to a type
long long.
Upon success, returns the converted value. If no conversion could be
performed or the value of base is not supported, returns 0.